"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var _exportNames = {
  updateComponentThemeMapForColorMode: true,
  resolveDefaultTheme: true,
  updateComponentThemeMap: true
};
exports.updateComponentThemeMap = exports.resolveDefaultTheme = exports.updateComponentThemeMapForColorMode = void 0;

var _lodash = _interopRequireDefault(require("lodash.get"));

var _ResolvedStyleMap = require("../core/ResolvedStyleMap");

Object.keys(_ResolvedStyleMap).forEach(function (key) {
  if (key === "default" || key === "__esModule") return;
  if (Object.prototype.hasOwnProperty.call(_exportNames, key)) return;
  if (key in exports && exports[key] === _ResolvedStyleMap[key]) return;
  Object.defineProperty(exports, key, {
    enumerable: true,
    get: function () {
      return _ResolvedStyleMap[key];
    }
  });
});

var _getStyledComponentAndObjects = require("./getStyledComponentAndObjects");

var _theme = require("../theme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//@ts-ignore
// eslint-disable-next-line dot-notation
// window['StyleSheet'] = StyleSheet;
// window['logger'] = {};
// console.batchTime = (key) => {
//   const keyValue = window['logger'][key];
//   if (keyValue) {
//     // keyValue.totalTime = keyValue.totalTime + (Date.now() - keyValue.startTime);
//     keyValue.startTime = window.performance.now();
//   } else {
//     window['logger'][key] = {
//       startTime: window.performance.now(),
//       totalTime: 0,
//     };
//   }
// };
// console.batchTimeEnd = (key) => {
//   const keyValue = window['logger'][key];
//   if (keyValue) {
//     keyValue.totalTime =
//       keyValue.totalTime + (window.performance.now() - keyValue.startTime);
//     // console.log(
//     //   "useStyledSystemPropsResolver 2222",
//     //   keyValue,
//     //   window.performance.now()
//     // );
//   }
// };
const resolveForInternalPseudoProps = (name, key, styledObj, config, mergeDefaultProps = true) => {
  // console.log(config, name, key, 'config here');
  // if (name !== 'Button') {
  //   return;
  // }
  for (const property in styledObj.internalPseudoProps) {
    if (_ResolvedStyleMap.PSEUDO_PROP_COMPONENT_MAP[property]) {
      // if (key === 'Button.sm') {
      //   console.log(
      //     mergeDefaultProps,
      //     key,
      //     PSEUDO_PROP_COMPONENT_MAP[property],
      //     '******'
      //   );
      // }
      updateComponentThemeMapForColorMode(_ResolvedStyleMap.PSEUDO_PROP_COMPONENT_MAP[property], "".concat(key, ".").concat(_ResolvedStyleMap.PSEUDO_PROP_COMPONENT_MAP[property]), styledObj.internalPseudoProps[property], config, false, mergeDefaultProps);
    } else {
      // const themeProps = getThemeProps(name, colorMode, {
      //   [pseudoPropStateMap[property]]: true,
      // });
      // if (property === '_hover') {
      //   console.log(
      //     // name,
      //     // property,
      //     // pseudoPropStateMap[property],
      //     themeProps,
      //     {
      //       ...themeProps.styleFromProps,
      //       ...styledObj.internalPseudoProps[property],
      //     },
      //     'theme props '
      //   );
      // }
      const styledObjNestedProp = (0, _getStyledComponentAndObjects.getStyledObject)(name, {}, config, styledObj.internalPseudoProps[property]);
      const componentMapPath = key;
      const componentObj = (0, _ResolvedStyleMap.get)(componentMapPath);

      if (componentObj) {
        // const stateKey = key.slice(componentMapPath.length + 1);
        if (_ResolvedStyleMap.pseudoPropStateMap[property]) {
          const stateKey = property;

          if (componentObj[stateKey]) {
            if (!componentObj[stateKey][config.colorMode]) {
              componentObj[stateKey][config.colorMode] = [];
            }

            componentObj[stateKey][config.colorMode].push(styledObjNestedProp);
          } else {
            componentObj[stateKey] = {
              [config.colorMode]: [styledObjNestedProp]
            };
          }
        } else {
          // console.log(
          //   'hello here &&&*',
          //   styledObj.internalPseudoProps[property]
          // );
          componentObj[config.colorMode][0].unResolvedProps = { ...componentObj[config.colorMode][0].unResolvedProps,
            [property]: styledObj.internalPseudoProps[property]
          };
        }
      }
    }
  }
};

const updateComponentThemeMapForColorMode = (name, key, inputProps, config = {
  colorMode: 'light',
  platform: 'web'
}, resolveForStatePseudoProps = false, mergeDefaultProps = true) => {
  let componentTheme = (0, _lodash.default)(_theme.theme, "components.".concat(name), {}); // resolve for variant

  if (resolveForStatePseudoProps) {
    componentTheme = {};
  }

  const styledObj = (0, _getStyledComponentAndObjects.getStyledObject)(name, componentTheme, config, { ...inputProps,
    extraProp: key
  }, mergeDefaultProps);
  (0, _ResolvedStyleMap.set)(key, styledObj, config.colorMode); // console.log(key, styledObj, config.colorMode, '&&&&&&');

  resolveForInternalPseudoProps(name, key, styledObj, config, mergeDefaultProps);
  return styledObj;
};

exports.updateComponentThemeMapForColorMode = updateComponentThemeMapForColorMode;

const resolveDefaultTheme = platform => {
  for (const key in _theme.theme.components) {
    updateComponentThemeMap(key, {}, {
      platform
    });
  }

  return _ResolvedStyleMap.resolvedStyledMap;
};

exports.resolveDefaultTheme = resolveDefaultTheme;

const updateComponentThemeMap = (name, inputProps, config = {
  platform: 'web',
  colorMode: 'light'
}, runTimeResolution = false, props) => {
  const {
    platform,
    colorMode
  } = config; // console.log(props, 'props here');

  const componentTheme = (0, _lodash.default)(_theme.theme, "components.".concat(name), {});
  let themeObj = {};

  if (runTimeResolution) {
    const currentColorScheme = props === null || props === void 0 ? void 0 : props.colorScheme; // || componentTheme?.defaultProps?.colorScheme;

    const currentVariant = props === null || props === void 0 ? void 0 : props.variant; // || componentTheme?.defaultProps?.variant;

    const currentSize = props === null || props === void 0 ? void 0 : props.size; // || componentTheme?.defaultProps?.size;

    if (currentVariant && currentColorScheme) {
      themeObj = updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(currentColorScheme, ".").concat(currentVariant), {
        variant: currentVariant,
        colorScheme: currentColorScheme
      }, {
        colorMode,
        platform
      });
    } else if (currentColorScheme) {
      themeObj = updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(currentColorScheme), {
        colorScheme: currentColorScheme
      }, {
        colorMode,
        platform
      });
    } else if (currentVariant) {
      themeObj = updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(currentVariant), {
        variant: currentVariant
      }, {
        colorMode,
        platform
      });
    } else if (currentSize) {
      // console.log(name, 'name here 111', currentSize);
      // if (name == 'Button') {
      //   console.trace('hh');
      // }
      themeObj = updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(currentSize), {
        size: currentSize
      }, {
        colorMode,
        platform
      }, false, false);
    } else {
      themeObj = updateComponentThemeMapForColorMode(name, name, inputProps, {
        colorMode,
        platform
      }, false, true);
    }

    return themeObj;
  }

  updateComponentThemeMapForColorMode(name, name, inputProps, {
    colorMode: 'light',
    platform
  });
  updateComponentThemeMapForColorMode(name, name, inputProps, {
    colorMode: 'dark',
    platform
  });

  if (_ResolvedStyleMap.COLOR_SCHEME_MAP[name]) {
    for (const color in _theme.theme.colors) {
      if (!['white', 'black', 'lightText', 'darkText', 'contrastThreshold'].includes(color)) {
        updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(color), {
          colorScheme: color
        }, {
          colorMode: 'light',
          platform
        } // true
        );
        updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(color), {
          colorScheme: color
        }, {
          colorMode: 'dark',
          platform
        } // true
        );

        for (const variant in componentTheme.variants) {
          updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(color, ".").concat(variant), {
            variant: variant,
            colorScheme: color
          }, {
            colorMode: 'light',
            platform
          } // true
          );
          updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(color, ".").concat(variant), {
            variant: variant,
            colorScheme: color
          }, {
            colorMode: 'dark',
            platform
          } // true
          );
        }
      } // console.log(color, 'hello &&&&&');

    }
  } else {
    for (const variant in componentTheme.variants) {
      updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(variant), {
        variant: variant
      }, {
        colorMode: 'light',
        platform
      } // true
      );
      updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(variant), {
        variant: variant
      }, {
        colorMode: 'dark',
        platform
      });
    }
  } // resolve for all sizes


  for (const size in componentTheme.sizes) {
    updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(size), {
      size: size
    }, {
      colorMode: 'light',
      platform
    }, false, false);
    updateComponentThemeMapForColorMode(name, "".concat(name, ".").concat(size), {
      size: size
    }, {
      colorMode: 'dark',
      platform
    }, false, false);
  }

  return {};
};

exports.updateComponentThemeMap = updateComponentThemeMap;
//# sourceMappingURL=styled.js.map